@@ -7,12 +7,12 @@
 import logging
 from decimal import Decimal as D
 
-
 from django.conf import settings
 from django.db import models
 from django.utils.safestring import mark_safe
 from django.utils.text import slugify
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
+
 # https://github.com/jedie/django-tools
 from django_tools.file_storage.file_system_storage import OverwriteFileSystemStorage
 from django_tools.models import UpdateTimeBaseModel
@@ -62,7 +62,9 @@ class GpxModel(ModelAdminUrlMixin, UpdateTimeBaseModel):
         blank=True,
     )
 
-    creator = models.CharField(help_text="Used device to create this track", max_length=511, null=True, blank=True)
+    creator = models.CharField(
+        help_text="Used device to create this track", max_length=511, null=True, blank=True
+    )
     track_svg = models.FileField(
         verbose_name=_("Track SVG"),
         upload_to=svg_upload_path,
@@ -71,15 +73,21 @@ class GpxModel(ModelAdminUrlMixin, UpdateTimeBaseModel):
         blank=True,
     )
 
-    start_time = models.DateTimeField(editable=False, help_text=_("Start time of the first segment in track"))
+    start_time = models.DateTimeField(
+        editable=False, help_text=_("Start time of the first segment in track")
+    )
     start_latitude = models.FloatField(
         editable=False, help_text=_("Latitude of the first recorded point from the *.gpx file")
     )
     start_longitude = models.FloatField(
         editable=False, help_text=_("Longitude of the first recorded point from the *.gpx file")
     )
-    start_temperature = models.FloatField(editable=True, null=True, blank=True, help_text=_("Temperature at start."))
-    start_weather_state = models.CharField(max_length=127, null=True, blank=True, help_text="Weather state at start.")
+    start_temperature = models.FloatField(
+        editable=True, null=True, blank=True, help_text=_("Temperature at start.")
+    )
+    start_weather_state = models.CharField(
+        max_length=127, null=True, blank=True, help_text="Weather state at start."
+    )
     short_start_address = models.CharField(
         max_length=255, null=True, blank=True, help_text="The short address of the start point"
     )
@@ -87,10 +95,16 @@ class GpxModel(ModelAdminUrlMixin, UpdateTimeBaseModel):
         max_length=255, null=True, blank=True, help_text="The full address of the start point"
     )
 
-    finish_time = models.DateTimeField(editable=False, help_text=_("End time of the last segment in track"))
+    finish_time = models.DateTimeField(
+        editable=False, help_text=_("End time of the last segment in track")
+    )
     finish_latitude = models.FloatField(editable=False, help_text=_("Latitude of the finish point"))
-    finish_longitude = models.FloatField(editable=False, help_text=_("Longitude of the finish point"))
-    finish_temperature = models.FloatField(editable=True, null=True, blank=True, help_text=_("Temperature at finish."))
+    finish_longitude = models.FloatField(
+        editable=False, help_text=_("Longitude of the finish point")
+    )
+    finish_temperature = models.FloatField(
+        editable=True, null=True, blank=True, help_text=_("Temperature at finish.")
+    )
     finish_weather_state = models.CharField(
         max_length=127, null=True, blank=True, help_text="Weather state at finish."
     )
@@ -118,11 +132,14 @@ class GpxModel(ModelAdminUrlMixin, UpdateTimeBaseModel):
         on_delete=models.SET_NULL,
     )
 
-    points_no = models.PositiveIntegerField(help_text=_("Number of points in GPX"), null=True, blank=True)
+    points_no = models.PositiveIntegerField(
+        help_text=_("Number of points in GPX"), null=True, blank=True
+    )
 
     length = models.PositiveIntegerField(
         help_text=_(
-            "Length in meters (calculated from GPX track 3-dimensional used latitude, longitude, and elevation)"
+            "Length in meters"
+            " (calculated from GPX track 3-dimensional used latitude, longitude, and elevation)"
         ),
         null=True,
         blank=True,
@@ -131,13 +148,18 @@ class GpxModel(ModelAdminUrlMixin, UpdateTimeBaseModel):
         to=DistanceModel,
         on_delete=models.SET_NULL,
         related_name="tracks",
-        help_text=_("Length in meters (calculated 3-dimensional used latitude, longitude, and elevation)"),
+        help_text=_(
+            "Length in meters (calculated 3-dimensional used latitude, longitude, and elevation)"
+        ),
         null=True,
         blank=True,
     )
 
     duration_s = models.PositiveIntegerField(
-        help_text=_("Duration in seconds (from the GPX track)"), editable=False, null=True, blank=True
+        help_text=_("Duration in seconds (from the GPX track)"),
+        editable=False,
+        null=True,
+        blank=True,
     )
     pace = models.DecimalField(
         help_text=_("Min/km (number of minutes it takes to cover a kilometer)"),
@@ -147,11 +169,19 @@ class GpxModel(ModelAdminUrlMixin, UpdateTimeBaseModel):
         blank=True,
     )
 
-    uphill = models.IntegerField(help_text=_("Uphill elevation climbs in meters"), null=True, blank=True)
-    downhill = models.IntegerField(help_text=_("Downhill elevation descent in meters"), null=True, blank=True)
+    uphill = models.IntegerField(
+        help_text=_("Uphill elevation climbs in meters"), null=True, blank=True
+    )
+    downhill = models.IntegerField(
+        help_text=_("Downhill elevation descent in meters"), null=True, blank=True
+    )
 
-    min_elevation = models.IntegerField(help_text=_("Minimum elevation in meters"), null=True, blank=True)
-    max_elevation = models.IntegerField(help_text=_("Maximum elevation in meters"), null=True, blank=True)
+    min_elevation = models.IntegerField(
+        help_text=_("Minimum elevation in meters"), null=True, blank=True
+    )
+    max_elevation = models.IntegerField(
+        help_text=_("Maximum elevation in meters"), null=True, blank=True
+    )
 
     heart_rate_min = models.PositiveIntegerField(
         help_text=_("Minimum heart rate."), null=True, blank=True, editable=False
@@ -182,10 +212,11 @@ class GpxModel(ModelAdminUrlMixin, UpdateTimeBaseModel):
         e.g:
             ~/DjangoForRunnersEnv/media/gpx_track_<date>/<prefix_id>.<file_extension>
         """
+        # settings.MEDIA_ROOT,
+        # TODO: Use https://github.com/jedie/django-tools/tree/master/django_tools/serve_media_app
         date_prefix = self.start_time.strftime("%Y_%m")
         upload_path = "/".join(
             (
-                # settings.MEDIA_ROOT,
                 self.tracked_by.username,
                 f"gpx_track_{date_prefix}",
                 f"{self.get_prefix_id()}.{file_extension}",
@@ -221,7 +252,9 @@ class GpxModel(ModelAdminUrlMixin, UpdateTimeBaseModel):
 
     def svg_tag_big(self):
         if self.track_svg:
-            html = f'<img src="{self.track_svg.url}" alt="gpx track" height="200px" width="200px" />'
+            html = (
+                f'<img src="{self.track_svg.url}" alt="gpx track" height="200px" width="200px" />'
+            )
             return mark_safe(html)
         return ""
 
@@ -375,19 +408,17 @@ class GpxModel(ModelAdminUrlMixin, UpdateTimeBaseModel):
     human_weather.admin_order_field = "start_temperature"
 
     def _coordinate2link(self, lat, lon):
+        url1 = (
+            'https://nominatim.openstreetmap.org/reverse'
+            f'?lat={lat}&lon={lon}&format=json&addressdetails=1'
+        )
+        url2 = f'https://www.openstreetmap.org/search?query={lat}%2C{lon}'
+        title = f'Reverse {lat},{lon} address with OpenStreepMap'
         html = (
-            "<a"
-            ' href="https://nominatim.openstreetmap.org/reverse?lat={lat}&lon={lon}&format=json&addressdetails=1"'
-            ' title="Reverse {lat},{lon} address with OpenStreepMap"'
-            ' target="_blank"'
-            ">reverse address</a>"
+            f'<a href="{url1}" title="{title}" target="_blank">reverse address</a>'
             "<br>"
-            "<a"
-            ' href="https://www.openstreetmap.org/search?query={lat}%2C{lon}"'
-            ' title="OpenStreepMap at {lat},{lon}"'
-            ' target="_blank"'
-            ">map</a>"
-        ).format(lat=lat, lon=lon)
+            f'<a href="{url2}" title="OpenStreepMap at {lat},{lon}" target="_blank">map</a>'
+        )
         return mark_safe(html)
 
     def start_coordinate_html(self):
@@ -476,33 +507,36 @@ class GpxModel(ModelAdminUrlMixin, UpdateTimeBaseModel):
             pace = (duration_s / 60) / distance_km
         except ZeroDivisionError:
             # FIXME
-            log.exception(f"Error calculate pace with duration {duration_s!r}sec and distance {distance_km}km!")
+            log.exception(
+                f"Error calculate pace with duration {duration_s!r}sec and distance {distance_km}km!"
+            )
         else:
             if pace > 99 or pace < 0:
                 log.error("Pace out of range: %f", pace)
             else:
                 self.pace = pace
 
-    def short_name(self, start_time=True):
+    def short_name(self, start_time=True, prefix_id=False):
         if self.pk is None:
             return "new, unsaved GPX Track"
 
-        if start_time:
-            parts = [self.start_time.strftime("%Y-%m-%d")]
-        else:
-            parts = []
+        parts = []
+        if prefix_id:
+            parts.append(self.get_prefix_id())
+        elif start_time:
+            parts.append(self.start_time.strftime("%Y-%m-%d"))
 
         if self.participation:
             parts.append(self.participation.event.name)
         else:
             parts.append(self.short_start_address)
-        result = " ".join([str(part) for part in parts if part])
+        result = " ".join(str(part) for part in parts if part)
         if result:
             return result
         return f"GPX Track ID:{self.pk}"
 
-    def get_short_slug(self):
-        name = self.short_name()
+    def get_short_slug(self, prefix_id=False):
+        name = self.short_name(prefix_id=prefix_id)
         return slugify(name)
 
     def get_prefix_id(self):
@@ -518,6 +552,13 @@ class GpxModel(ModelAdminUrlMixin, UpdateTimeBaseModel):
         verbose_name = _("GPX Track")
         verbose_name_plural = _("GPX Tracks")
         unique_together = (
-            ("start_time", "start_latitude", "start_longitude", "finish_time", "finish_latitude", "finish_longitude"),
+            (
+                "start_time",
+                "start_latitude",
+                "start_longitude",
+                "finish_time",
+                "finish_latitude",
+                "finish_longitude",
+            ),
         )
         ordering = ("-start_time", "-pk")
